@@ -2,6 +2,7 @@
 
 # Author: Wei Xue <xuewei4d@gmail.com>
 # Modified by Thierry Guillemot <thierry.guillemot.work@gmail.com>
+# Modified by Colin Weber <colin.weber.27@gmail.com>
 # License: BSD 3 clause
 
 import warnings
@@ -564,10 +565,12 @@ class BaseMixture(DensityMixin, BaseEstimator, metaclass=ABCMeta):
 
 
 class PhaseConstrainedBaseMixture(DensityMixin, BaseEstimator, metaclass=ABCMeta):
-    """Base class for phase constrained mixture models.
+    """Base class for phase first mixture models.
 
-    This abstract class specifies an interface for all mixture classes and
-    provides basic common methods for mixture models.
+    This abstract class specifies an interface for the phase first Gaussian Model and
+    provides its basic methods.
+
+    This class was written by Colin Weber.
     """
 
     def __init__(self, n_components, tol, reg_covar,
@@ -713,6 +716,14 @@ class PhaseConstrainedBaseMixture(DensityMixin, BaseEstimator, metaclass=ABCMeta
         initialization is performed upon the first call. Upon consecutive
         calls, training starts where it left off.
 
+        This method is meant to be used with a data set in polar coordinates. First, it
+        fits to the phase dimension only. Then, it uses the results of this fit to
+        initialize the fit on the full polar dataset. Furthermore, in the second fit, the
+        phase coordinate of the means is restricted to the mean phases found in the
+        first fit.
+
+        This method was written by Colin Weber,
+
         Parameters
         ----------
         X : array-like, shape (n_samples, n_features)
@@ -823,6 +834,14 @@ class PhaseConstrainedBaseMixture(DensityMixin, BaseEstimator, metaclass=ABCMeta
         raised. After fitting, it predicts the most probable label for the
         input data points.
 
+        This method is meant to be used with a data set in polar coordinates. First, it
+        fits to the phase dimension only. Then, it uses the results of this fit to
+        initialize the fit on the full polar dataset. Furthermore, in the second fit, the
+        phase coordinate of the means is restricted to the mean phases found in the
+        first fit.
+
+        Written by Colin Weber
+
         .. versionadded:: 0.20
 
         Parameters
@@ -917,23 +936,11 @@ class PhaseConstrainedBaseMixture(DensityMixin, BaseEstimator, metaclass=ABCMeta
         log_prob_norm, log_resp = self._estimate_log_prob_resp(X)
         return np.mean(log_prob_norm), log_resp
 
-    # @abstractmethod
-    # def _m_step(self, X, log_resp):
-    #     """M step.
-    #
-    #     Parameters
-    #     ----------
-    #     X : array-like, shape (n_samples, n_features)
-    #
-    #     log_resp : array-like, shape (n_samples, n_components)
-    #         Logarithm of the posterior probabilities (or responsibilities) of
-    #         the point of each sample in X.
-    #     """
-    #     pass
-
     @abstractmethod
     def _phase_constrained_m_step(self, X, log_resp):
-        """M step.
+        """M step for the phase first fit.
+
+        Written by Colin Weber
 
         Parameters
         ----------
